/* A Bison parser, made by GNU Bison 3.0.4.  */

/* Bison implementation for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Bison version.  */
#define YYBISON_VERSION "3.0.4"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 2

/* Push parsers.  */
#define YYPUSH 0

/* Pull parsers.  */
#define YYPULL 1

/* Substitute the type names.  */
#define YYSTYPE         SERV_STYPE
/* Substitute the variable and function names.  */
#define yyparse         serv_parse
#define yylex           serv_lex
#define yyerror         serv_error
#define yydebug         serv_debug
#define yynerrs         serv_nerrs


/* Copy the first part of user declarations.  */
#line 54 "parser/serverFile.y" /* yacc.c:339  */
  
#include "mediatex-config.h"
  /* yyscan_t is pre-defined by mediatex-config.h and will be defined
     by Flex header bellow */

#line 79 "parser/serverFile.tab.c" /* yacc.c:339  */

# ifndef YY_NULLPTR
#  if defined __cplusplus && 201103L <= __cplusplus
#   define YY_NULLPTR nullptr
#  else
#   define YY_NULLPTR 0
#  endif
# endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 1
#endif

/* In a future release of Bison, this section will be replaced
   by #include "serverFile.tab.h".  */
#ifndef YY_SERV_PARSER_SERVERFILE_TAB_H_INCLUDED
# define YY_SERV_PARSER_SERVERFILE_TAB_H_INCLUDED
/* Debug traces.  */
#ifndef SERV_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define SERV_DEBUG 1
#  else
#   define SERV_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define SERV_DEBUG 1
# endif /* ! defined YYDEBUG */
#endif  /* ! defined SERV_DEBUG */
#if SERV_DEBUG
extern int serv_debug;
#endif

/* Token type.  */
#ifndef SERV_TOKENTYPE
# define SERV_TOKENTYPE
  enum serv_tokentype
  {
    servMASTER = 258,
    servSERVER = 259,
    servCOMMENT = 260,
    servHTTPS = 261,
    servLOGAPACHE = 262,
    servLOGGIT = 263,
    servLOGAUDIT = 264,
    servLABEL = 265,
    servHOST = 266,
    servLASTCOMMIT = 267,
    servNETWORKS = 268,
    servGATEWAYS = 269,
    servMDTXPORT = 270,
    servSSHPORT = 271,
    servWWWPORT = 272,
    servDNSHOST = 273,
    servCOLLKEY = 274,
    servUSERKEY = 275,
    servHOSTKEY = 276,
    servPROVIDE = 277,
    servCOMMA = 278,
    servCOLON = 279,
    servEQUAL = 280,
    servENDBLOCK = 281,
    servCACHESIZE = 282,
    servCACHETTL = 283,
    servQUERYTTL = 284,
    servSUPPTTL = 285,
    servUPLOADTTL = 286,
    servSERVERTTL = 287,
    servMAXSCORE = 288,
    servBADSCORE = 289,
    servPOWSUPP = 290,
    servFACTSUPP = 291,
    servFILESCORE = 292,
    servMINGEODUP = 293,
    servERROR = 294,
    servSTRING = 295,
    servNUMBER = 296,
    servSCORE = 297,
    servHASH = 298,
    servSIZE = 299,
    servTIME = 300,
    servDATE = 301,
    servBOOLEAN = 302
  };
#endif
/* Tokens.  */
#define servMASTER 258
#define servSERVER 259
#define servCOMMENT 260
#define servHTTPS 261
#define servLOGAPACHE 262
#define servLOGGIT 263
#define servLOGAUDIT 264
#define servLABEL 265
#define servHOST 266
#define servLASTCOMMIT 267
#define servNETWORKS 268
#define servGATEWAYS 269
#define servMDTXPORT 270
#define servSSHPORT 271
#define servWWWPORT 272
#define servDNSHOST 273
#define servCOLLKEY 274
#define servUSERKEY 275
#define servHOSTKEY 276
#define servPROVIDE 277
#define servCOMMA 278
#define servCOLON 279
#define servEQUAL 280
#define servENDBLOCK 281
#define servCACHESIZE 282
#define servCACHETTL 283
#define servQUERYTTL 284
#define servSUPPTTL 285
#define servUPLOADTTL 286
#define servSERVERTTL 287
#define servMAXSCORE 288
#define servBADSCORE 289
#define servPOWSUPP 290
#define servFACTSUPP 291
#define servFILESCORE 292
#define servMINGEODUP 293
#define servERROR 294
#define servSTRING 295
#define servNUMBER 296
#define servSCORE 297
#define servHASH 298
#define servSIZE 299
#define servTIME 300
#define servDATE 301
#define servBOOLEAN 302

/* Value type.  */
#if ! defined SERV_STYPE && ! defined SERV_STYPE_IS_DECLARED

union SERV_STYPE
{
#line 60 "parser/serverFile.y" /* yacc.c:355  */

  off_t  number;
  off_t  size;
  time_t time;
  float  score;
  int    boolean;
  char   string[(MAX_SIZE_STRING+1)*2]; // keys needs more place
  char   hash[MAX_SIZE_MD5+1];

#line 231 "parser/serverFile.tab.c" /* yacc.c:355  */
};

typedef union SERV_STYPE SERV_STYPE;
# define SERV_STYPE_IS_TRIVIAL 1
# define SERV_STYPE_IS_DECLARED 1
#endif



int serv_parse (yyscan_t yyscanner, Collection* coll, Server* server);
/* "%code provides" blocks.  */
#line 26 "parser/serverFile.y" /* yacc.c:355  */

/*=======================================================================
 * Version: this file is generated by BISON using serverFile.y
 * Project: MediaTeX
 * Module : server parser
 *
 * server file parser

 MediaTex is an Electronic Records Management System
 Copyright (C) 2014 2015 2016 2017 Nicolas Roche
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/

#define YYSTYPE SERV_STYPE

#line 271 "parser/serverFile.tab.c" /* yacc.c:355  */

#endif /* !YY_SERV_PARSER_SERVERFILE_TAB_H_INCLUDED  */

/* Copy the second part of user declarations.  */
#line 70 "parser/serverFile.y" /* yacc.c:358  */

  // upper YYSTYPE union is required by Flex headers
#include "parser/serverFile.h"

#define LINENO serv_get_lineno(yyscanner)
  
void serv_error(yyscan_t yyscanner, Collection* coll, Server* server,
		const char* message);

#line 286 "parser/serverFile.tab.c" /* yacc.c:358  */

#ifdef short
# undef short
#endif

#ifdef YYTYPE_UINT8
typedef YYTYPE_UINT8 yytype_uint8;
#else
typedef unsigned char yytype_uint8;
#endif

#ifdef YYTYPE_INT8
typedef YYTYPE_INT8 yytype_int8;
#else
typedef signed char yytype_int8;
#endif

#ifdef YYTYPE_UINT16
typedef YYTYPE_UINT16 yytype_uint16;
#else
typedef unsigned short int yytype_uint16;
#endif

#ifdef YYTYPE_INT16
typedef YYTYPE_INT16 yytype_int16;
#else
typedef short int yytype_int16;
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif ! defined YYSIZE_T
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned int
# endif
#endif

#define YYSIZE_MAXIMUM ((YYSIZE_T) -1)

#ifndef YY_
# if defined YYENABLE_NLS && YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(Msgid) Msgid
# endif
#endif

#ifndef YY_ATTRIBUTE
# if (defined __GNUC__                                               \
      && (2 < __GNUC__ || (__GNUC__ == 2 && 96 <= __GNUC_MINOR__)))  \
     || defined __SUNPRO_C && 0x5110 <= __SUNPRO_C
#  define YY_ATTRIBUTE(Spec) __attribute__(Spec)
# else
#  define YY_ATTRIBUTE(Spec) /* empty */
# endif
#endif

#ifndef YY_ATTRIBUTE_PURE
# define YY_ATTRIBUTE_PURE   YY_ATTRIBUTE ((__pure__))
#endif

#ifndef YY_ATTRIBUTE_UNUSED
# define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
#endif

#if !defined _Noreturn \
     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
# if defined _MSC_VER && 1200 <= _MSC_VER
#  define _Noreturn __declspec (noreturn)
# else
#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YYUSE(E) ((void) (E))
#else
# define YYUSE(E) /* empty */
#endif

#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
/* Suppress an incorrect diagnostic about yylval being uninitialized.  */
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
    _Pragma ("GCC diagnostic push") \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")\
    _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
# define YY_IGNORE_MAYBE_UNINITIALIZED_END \
    _Pragma ("GCC diagnostic pop")
#else
# define YY_INITIAL_VALUE(Value) Value
#endif
#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_END
#endif
#ifndef YY_INITIAL_VALUE
# define YY_INITIAL_VALUE(Value) /* Nothing. */
#endif


#if ! defined yyoverflow || YYERROR_VERBOSE

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   elif defined __BUILTIN_VA_ARG_INCR
#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
#   elif defined _AIX
#    define YYSTACK_ALLOC __alloca
#   elif defined _MSC_VER
#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
#    define alloca _alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if ! defined _ALLOCA_H && ! defined EXIT_SUCCESS
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
      /* Use EXIT_SUCCESS as a witness for stdlib.h.  */
#     ifndef EXIT_SUCCESS
#      define EXIT_SUCCESS 0
#     endif
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's 'empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined EXIT_SUCCESS \
       && ! ((defined YYMALLOC || defined malloc) \
             && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef EXIT_SUCCESS
#    define EXIT_SUCCESS 0
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined EXIT_SUCCESS
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined EXIT_SUCCESS
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* ! defined yyoverflow || YYERROR_VERBOSE */


#if (! defined yyoverflow \
     && (! defined __cplusplus \
         || (defined SERV_STYPE_IS_TRIVIAL && SERV_STYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yytype_int16 yyss_alloc;
  YYSTYPE yyvs_alloc;
};

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (yytype_int16) + sizeof (YYSTYPE)) \
      + YYSTACK_GAP_MAXIMUM)

# define YYCOPY_NEEDED 1

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack_alloc, Stack)                           \
    do                                                                  \
      {                                                                 \
        YYSIZE_T yynewbytes;                                            \
        YYCOPY (&yyptr->Stack_alloc, Stack, yysize);                    \
        Stack = &yyptr->Stack_alloc;                                    \
        yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
        yyptr += yynewbytes / sizeof (*yyptr);                          \
      }                                                                 \
    while (0)

#endif

#if defined YYCOPY_NEEDED && YYCOPY_NEEDED
/* Copy COUNT objects from SRC to DST.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(Dst, Src, Count) \
      __builtin_memcpy (Dst, Src, (Count) * sizeof (*(Src)))
#  else
#   define YYCOPY(Dst, Src, Count)              \
      do                                        \
        {                                       \
          YYSIZE_T yyi;                         \
          for (yyi = 0; yyi < (Count); yyi++)   \
            (Dst)[yyi] = (Src)[yyi];            \
        }                                       \
      while (0)
#  endif
# endif
#endif /* !YYCOPY_NEEDED */

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  36
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   111

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  48
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  16
/* YYNRULES -- Number of rules.  */
#define YYNRULES  54
/* YYNSTATES -- Number of states.  */
#define YYNSTATES  101

/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
   by yylex, with out-of-bounds checking.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   302

#define YYTRANSLATE(YYX)                                                \
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex, without out-of-bounds checking.  */
static const yytype_uint8 yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47
};

#if SERV_DEBUG
  /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
static const yytype_uint16 yyrline[] =
{
       0,   144,   144,   147,   151,   157,   161,   167,   172,   176,
     180,   185,   195,   205,   215,   219,   223,   227,   231,   235,
     239,   243,   247,   253,   257,   263,   280,   287,   288,   290,
     291,   293,   297,   301,   305,   309,   310,   311,   315,   319,
     323,   327,   331,   335,   339,   343,   346,   347,   350,   372,
     373,   376,   377,   380,   387
};
#endif

#if SERV_DEBUG || YYERROR_VERBOSE || 1
/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "servMASTER", "servSERVER",
  "servCOMMENT", "servHTTPS", "servLOGAPACHE", "servLOGGIT",
  "servLOGAUDIT", "servLABEL", "servHOST", "servLASTCOMMIT",
  "servNETWORKS", "servGATEWAYS", "servMDTXPORT", "servSSHPORT",
  "servWWWPORT", "servDNSHOST", "servCOLLKEY", "servUSERKEY",
  "servHOSTKEY", "servPROVIDE", "servCOMMA", "servCOLON", "servEQUAL",
  "servENDBLOCK", "servCACHESIZE", "servCACHETTL", "servQUERYTTL",
  "servSUPPTTL", "servUPLOADTTL", "servSERVERTTL", "servMAXSCORE",
  "servBADSCORE", "servPOWSUPP", "servFACTSUPP", "servFILESCORE",
  "servMINGEODUP", "servERROR", "servSTRING", "servNUMBER", "servSCORE",
  "servHASH", "servSIZE", "servTIME", "servDATE", "servBOOLEAN", "$accept",
  "file", "headers", "header", "stanzas", "stanza", "server", "lines2",
  "lines", "line", "images", "image", "networks", "gateways", "network",
  "gateway", YY_NULLPTR
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[NUM] -- (External) token number corresponding to the
   (internal) symbol number NUM (which must be that of a token).  */
static const yytype_uint16 yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,   286,   287,   288,   289,   290,   291,   292,   293,   294,
     295,   296,   297,   298,   299,   300,   301,   302
};
# endif

#define YYPACT_NINF -42

#define yypact_value_is_default(Yystate) \
  (!!((Yystate) == (-42)))

#define YYTABLE_NINF -1

#define yytable_value_is_error(Yytable_value) \
  0

  /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
     STATE-NUM.  */
static const yytype_int8 yypact[] =
{
      33,   -41,   -40,   -39,   -38,   -37,   -29,   -28,   -27,   -24,
     -23,   -22,   -21,   -20,   -19,   -18,   -16,    13,    -3,   -42,
     -42,   -42,   -42,   -42,   -42,   -42,   -42,   -26,    -8,    -7,
     -42,   -42,   -42,   -42,   -42,   -42,   -42,   -17,   -42,    39,
     -42,   -42,   -42,   -42,   -42,    67,   -42,     4,     5,     6,
       1,     8,     9,    12,    14,    15,    10,    17,    11,    18,
      19,    20,    32,    67,   -42,   -42,   -42,   -42,   -42,   -42,
      50,   -42,   -42,    51,   -42,   -42,   -42,   -42,   -42,   -42,
      38,    52,   -42,    41,    31,    45,   -42,   -42,     8,     9,
      56,    11,   -42,   -42,   -42,   -42,   -42,    61,   -42,    49,
     -42
};

  /* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
     Performed when YYTABLE does not specify something else to do.  Zero
     means the default is an error.  */
static const yytype_uint8 yydefact[] =
{
       2,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     3,     6,
       7,    10,    11,    12,    13,     8,     9,     0,     0,     0,
      17,    18,    19,    20,    21,    22,     1,     0,     5,     4,
      24,    15,    16,    14,    26,    28,    23,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,    27,    30,    32,    31,    33,    34,    53,
      35,    50,    54,    36,    52,    37,    38,    39,    40,    41,
       0,    45,    47,     0,     0,     0,    25,    29,     0,     0,
       0,     0,    42,    43,    44,    49,    51,     0,    46,     0,
      48
};

  /* YYPGOTO[NTERM-NUM].  */
static const yytype_int8 yypgoto[] =
{
     -42,   -42,   -42,    74,   -42,    54,   -42,   -42,   -42,    35,
     -42,    16,   -42,   -42,    21,    22
};

  /* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int8 yydefgoto[] =
{
      -1,    17,    18,    19,    39,    40,    45,    62,    63,    64,
      81,    82,    70,    73,    71,    74
};

  /* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
     positive, shift that token.  If negative, reduce the rule whose
     number is the opposite.  If YYTABLE_NINF, syntax error.  */
static const yytype_uint8 yytable[] =
{
       1,    37,    20,     2,     3,     4,     5,    21,    22,    23,
      24,    25,    26,    36,    27,     6,     7,    28,    29,    41,
      30,    31,    32,    33,    34,    35,    44,     8,     9,    10,
      11,    12,    13,    14,    15,    16,     1,    42,    43,     2,
       3,     4,     5,    37,    65,    66,    67,    68,    69,    72,
      78,     6,     7,    75,    80,    76,    77,    79,    86,    83,
      84,    85,    90,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    47,    88,    89,    91,    93,    48,    49,    50,
      51,    52,    53,    54,    55,    92,    99,    56,    57,    58,
      94,   100,    38,    46,    59,    60,    61,    97,    87,     0,
       0,     0,     0,     0,     0,     0,     0,    98,     0,    95,
       0,    96
};

static const yytype_int8 yycheck[] =
{
       3,     4,    43,     6,     7,     8,     9,    47,    47,    47,
      47,    40,    40,     0,    41,    18,    19,    41,    41,    45,
      42,    42,    42,    42,    42,    41,    43,    30,    31,    32,
      33,    34,    35,    36,    37,    38,     3,    45,    45,     6,
       7,     8,     9,     4,    40,    40,    40,    46,    40,    40,
      40,    18,    19,    41,    43,    41,    41,    40,    26,    41,
      41,    41,    24,    30,    31,    32,    33,    34,    35,    36,
      37,    38,     5,    23,    23,    23,    45,    10,    11,    12,
      13,    14,    15,    16,    17,    44,    25,    20,    21,    22,
      45,    42,    18,    39,    27,    28,    29,    41,    63,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    91,    -1,    88,
      -1,    89
};

  /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
     symbol of state STATE-NUM.  */
static const yytype_uint8 yystos[] =
{
       0,     3,     6,     7,     8,     9,    18,    19,    30,    31,
      32,    33,    34,    35,    36,    37,    38,    49,    50,    51,
      43,    47,    47,    47,    47,    40,    40,    41,    41,    41,
      42,    42,    42,    42,    42,    41,     0,     4,    51,    52,
      53,    45,    45,    45,    43,    54,    53,     5,    10,    11,
      12,    13,    14,    15,    16,    17,    20,    21,    22,    27,
      28,    29,    55,    56,    57,    40,    40,    40,    46,    40,
      60,    62,    40,    61,    63,    41,    41,    41,    40,    40,
      43,    58,    59,    41,    41,    41,    26,    57,    23,    23,
      24,    23,    44,    45,    45,    62,    63,    41,    59,    25,
      42
};

  /* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const yytype_uint8 yyr1[] =
{
       0,    48,    49,    49,    49,    50,    50,    51,    51,    51,
      51,    51,    51,    51,    51,    51,    51,    51,    51,    51,
      51,    51,    51,    52,    52,    53,    54,    55,    55,    56,
      56,    57,    57,    57,    57,    57,    57,    57,    57,    57,
      57,    57,    57,    57,    57,    57,    58,    58,    59,    60,
      60,    61,    61,    62,    63
};

  /* YYR2[YYN] -- Number of symbols on the right hand side of rule YYN.  */
static const yytype_uint8 yyr2[] =
{
       0,     2,     0,     1,     2,     2,     1,     2,     2,     2,
       2,     2,     2,     2,     3,     3,     3,     2,     2,     2,
       2,     2,     2,     2,     1,     4,     1,     1,     0,     2,
       1,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     3,     3,     3,     2,     3,     1,     5,     3,
       1,     3,     1,     1,     1
};


#define yyerrok         (yyerrstatus = 0)
#define yyclearin       (yychar = YYEMPTY)
#define YYEMPTY         (-2)
#define YYEOF           0

#define YYACCEPT        goto yyacceptlab
#define YYABORT         goto yyabortlab
#define YYERROR         goto yyerrorlab


#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)                                  \
do                                                              \
  if (yychar == YYEMPTY)                                        \
    {                                                           \
      yychar = (Token);                                         \
      yylval = (Value);                                         \
      YYPOPSTACK (yylen);                                       \
      yystate = *yyssp;                                         \
      goto yybackup;                                            \
    }                                                           \
  else                                                          \
    {                                                           \
      yyerror (yyscanner, coll, server, YY_("syntax error: cannot back up")); \
      YYERROR;                                                  \
    }                                                           \
while (0)

/* Error token number */
#define YYTERROR        1
#define YYERRCODE       256



/* Enable debugging if requested.  */
#if SERV_DEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)                        \
do {                                            \
  if (yydebug)                                  \
    YYFPRINTF Args;                             \
} while (0)

/* This macro is provided for backward compatibility. */
#ifndef YY_LOCATION_PRINT
# define YY_LOCATION_PRINT(File, Loc) ((void) 0)
#endif


# define YY_SYMBOL_PRINT(Title, Type, Value, Location)                    \
do {                                                                      \
  if (yydebug)                                                            \
    {                                                                     \
      YYFPRINTF (stderr, "%s ", Title);                                   \
      yy_symbol_print (stderr,                                            \
                  Type, Value, yyscanner, coll, server); \
      YYFPRINTF (stderr, "\n");                                           \
    }                                                                     \
} while (0)


/*----------------------------------------.
| Print this symbol's value on YYOUTPUT.  |
`----------------------------------------*/

static void
yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, yyscan_t yyscanner, Collection* coll, Server* server)
{
  FILE *yyo = yyoutput;
  YYUSE (yyo);
  YYUSE (yyscanner);
  YYUSE (coll);
  YYUSE (server);
  if (!yyvaluep)
    return;
# ifdef YYPRINT
  if (yytype < YYNTOKENS)
    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# endif
  YYUSE (yytype);
}


/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

static void
yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, yyscan_t yyscanner, Collection* coll, Server* server)
{
  YYFPRINTF (yyoutput, "%s %s (",
             yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);

  yy_symbol_value_print (yyoutput, yytype, yyvaluep, yyscanner, coll, server);
  YYFPRINTF (yyoutput, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

static void
yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
{
  YYFPRINTF (stderr, "Stack now");
  for (; yybottom <= yytop; yybottom++)
    {
      int yybot = *yybottom;
      YYFPRINTF (stderr, " %d", yybot);
    }
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)                            \
do {                                                            \
  if (yydebug)                                                  \
    yy_stack_print ((Bottom), (Top));                           \
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

static void
yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, yyscan_t yyscanner, Collection* coll, Server* server)
{
  unsigned long int yylno = yyrline[yyrule];
  int yynrhs = yyr2[yyrule];
  int yyi;
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
             yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr,
                       yystos[yyssp[yyi + 1 - yynrhs]],
                       &(yyvsp[(yyi + 1) - (yynrhs)])
                                              , yyscanner, coll, server);
      YYFPRINTF (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)          \
do {                                    \
  if (yydebug)                          \
    yy_reduce_print (yyssp, yyvsp, Rule, yyscanner, coll, server); \
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !SERV_DEBUG */
# define YYDPRINTF(Args)
# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !SERV_DEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif


#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined __GLIBC__ && defined _STRING_H
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
static YYSIZE_T
yystrlen (const char *yystr)
{
  YYSIZE_T yylen;
  for (yylen = 0; yystr[yylen]; yylen++)
    continue;
  return yylen;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined __GLIBC__ && defined _STRING_H && defined _GNU_SOURCE
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
yystpcpy (char *yydest, const char *yysrc)
{
  char *yyd = yydest;
  const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

# ifndef yytnamerr
/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
   quotes and backslashes, so that it's suitable for yyerror.  The
   heuristic is that double-quoting is unnecessary unless the string
   contains an apostrophe, a comma, or backslash (other than
   backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
   null, do not copy; instead, return the length of what the result
   would have been.  */
static YYSIZE_T
yytnamerr (char *yyres, const char *yystr)
{
  if (*yystr == '"')
    {
      YYSIZE_T yyn = 0;
      char const *yyp = yystr;

      for (;;)
        switch (*++yyp)
          {
          case '\'':
          case ',':
            goto do_not_strip_quotes;

          case '\\':
            if (*++yyp != '\\')
              goto do_not_strip_quotes;
            /* Fall through.  */
          default:
            if (yyres)
              yyres[yyn] = *yyp;
            yyn++;
            break;

          case '"':
            if (yyres)
              yyres[yyn] = '\0';
            return yyn;
          }
    do_not_strip_quotes: ;
    }

  if (! yyres)
    return yystrlen (yystr);

  return yystpcpy (yyres, yystr) - yyres;
}
# endif

/* Copy into *YYMSG, which is of size *YYMSG_ALLOC, an error message
   about the unexpected token YYTOKEN for the state stack whose top is
   YYSSP.

   Return 0 if *YYMSG was successfully written.  Return 1 if *YYMSG is
   not large enough to hold the message.  In that case, also set
   *YYMSG_ALLOC to the required number of bytes.  Return 2 if the
   required number of bytes is too large to store.  */
static int
yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                yytype_int16 *yyssp, int yytoken)
{
  YYSIZE_T yysize0 = yytnamerr (YY_NULLPTR, yytname[yytoken]);
  YYSIZE_T yysize = yysize0;
  enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
  /* Internationalized format string. */
  const char *yyformat = YY_NULLPTR;
  /* Arguments of yyformat. */
  char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
  /* Number of reported tokens (one for the "unexpected", one per
     "expected"). */
  int yycount = 0;

  /* There are many possibilities here to consider:
     - If this state is a consistent state with a default action, then
       the only way this function was invoked is if the default action
       is an error action.  In that case, don't check for expected
       tokens because there are none.
     - The only way there can be no lookahead present (in yychar) is if
       this state is a consistent state with a default action.  Thus,
       detecting the absence of a lookahead is sufficient to determine
       that there is no unexpected or expected token to report.  In that
       case, just report a simple "syntax error".
     - Don't assume there isn't a lookahead just because this state is a
       consistent state with a default action.  There might have been a
       previous inconsistent state, consistent state with a non-default
       action, or user semantic action that manipulated yychar.
     - Of course, the expected token list depends on states to have
       correct lookahead information, and it depends on the parser not
       to perform extra reductions after fetching a lookahead from the
       scanner and before detecting a syntax error.  Thus, state merging
       (from LALR or IELR) and default reductions corrupt the expected
       token list.  However, the list is correct for canonical LR with
       one exception: it will still contain any token that will not be
       accepted due to an error action in a later state.
  */
  if (yytoken != YYEMPTY)
    {
      int yyn = yypact[*yyssp];
      yyarg[yycount++] = yytname[yytoken];
      if (!yypact_value_is_default (yyn))
        {
          /* Start YYX at -YYN if negative to avoid negative indexes in
             YYCHECK.  In other words, skip the first -YYN actions for
             this state because they are default actions.  */
          int yyxbegin = yyn < 0 ? -yyn : 0;
          /* Stay within bounds of both yycheck and yytname.  */
          int yychecklim = YYLAST - yyn + 1;
          int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
          int yyx;

          for (yyx = yyxbegin; yyx < yyxend; ++yyx)
            if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR
                && !yytable_value_is_error (yytable[yyx + yyn]))
              {
                if (yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
                  {
                    yycount = 1;
                    yysize = yysize0;
                    break;
                  }
                yyarg[yycount++] = yytname[yyx];
                {
                  YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
                  if (! (yysize <= yysize1
                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
                    return 2;
                  yysize = yysize1;
                }
              }
        }
    }

  switch (yycount)
    {
# define YYCASE_(N, S)                      \
      case N:                               \
        yyformat = S;                       \
      break
      YYCASE_(0, YY_("syntax error"));
      YYCASE_(1, YY_("syntax error, unexpected %s"));
      YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
      YYCASE_(3, YY_("syntax error, unexpected %s, expecting %s or %s"));
      YYCASE_(4, YY_("syntax error, unexpected %s, expecting %s or %s or %s"));
      YYCASE_(5, YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s"));
# undef YYCASE_
    }

  {
    YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
      return 2;
    yysize = yysize1;
  }

  if (*yymsg_alloc < yysize)
    {
      *yymsg_alloc = 2 * yysize;
      if (! (yysize <= *yymsg_alloc
             && *yymsg_alloc <= YYSTACK_ALLOC_MAXIMUM))
        *yymsg_alloc = YYSTACK_ALLOC_MAXIMUM;
      return 1;
    }

  /* Avoid sprintf, as that infringes on the user's name space.
     Don't have undefined behavior even if the translation
     produced a string with the wrong number of "%s"s.  */
  {
    char *yyp = *yymsg;
    int yyi = 0;
    while ((*yyp = *yyformat) != '\0')
      if (*yyp == '%' && yyformat[1] == 's' && yyi < yycount)
        {
          yyp += yytnamerr (yyp, yyarg[yyi++]);
          yyformat += 2;
        }
      else
        {
          yyp++;
          yyformat++;
        }
  }
  return 0;
}
#endif /* YYERROR_VERBOSE */

/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

static void
yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep, yyscan_t yyscanner, Collection* coll, Server* server)
{
  YYUSE (yyvaluep);
  YYUSE (yyscanner);
  YYUSE (coll);
  YYUSE (server);
  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YYUSE (yytype);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}




/*----------.
| yyparse.  |
`----------*/

int
yyparse (yyscan_t yyscanner, Collection* coll, Server* server)
{
/* The lookahead symbol.  */
int yychar;


/* The semantic value of the lookahead symbol.  */
/* Default value used for initialization, for pacifying older GCCs
   or non-GCC compilers.  */
YY_INITIAL_VALUE (static YYSTYPE yyval_default;)
YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);

    /* Number of syntax errors so far.  */
    int yynerrs;

    int yystate;
    /* Number of tokens to shift before error messages enabled.  */
    int yyerrstatus;

    /* The stacks and their tools:
       'yyss': related to states.
       'yyvs': related to semantic values.

       Refer to the stacks through separate pointers, to allow yyoverflow
       to reallocate them elsewhere.  */

    /* The state stack.  */
    yytype_int16 yyssa[YYINITDEPTH];
    yytype_int16 *yyss;
    yytype_int16 *yyssp;

    /* The semantic value stack.  */
    YYSTYPE yyvsa[YYINITDEPTH];
    YYSTYPE *yyvs;
    YYSTYPE *yyvsp;

    YYSIZE_T yystacksize;

  int yyn;
  int yyresult;
  /* Lookahead token as an internal (translated) token number.  */
  int yytoken = 0;
  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;

#if YYERROR_VERBOSE
  /* Buffer for error messages, and its allocated size.  */
  char yymsgbuf[128];
  char *yymsg = yymsgbuf;
  YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
#endif

#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))

  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  yyssp = yyss = yyssa;
  yyvsp = yyvs = yyvsa;
  yystacksize = YYINITDEPTH;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY; /* Cause a token to be read.  */
  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
        /* Give user a chance to reallocate the stack.  Use copies of
           these so that the &'s don't force the real ones into
           memory.  */
        YYSTYPE *yyvs1 = yyvs;
        yytype_int16 *yyss1 = yyss;

        /* Each stack pointer address is followed by the size of the
           data in use in that stack, in bytes.  This used to be a
           conditional around just the two extra args, but that might
           be undefined if yyoverflow is a macro.  */
        yyoverflow (YY_("memory exhausted"),
                    &yyss1, yysize * sizeof (*yyssp),
                    &yyvs1, yysize * sizeof (*yyvsp),
                    &yystacksize);

        yyss = yyss1;
        yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyexhaustedlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
        goto yyexhaustedlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
        yystacksize = YYMAXDEPTH;

      {
        yytype_int16 *yyss1 = yyss;
        union yyalloc *yyptr =
          (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
        if (! yyptr)
          goto yyexhaustedlab;
        YYSTACK_RELOCATE (yyss_alloc, yyss);
        YYSTACK_RELOCATE (yyvs_alloc, yyvs);
#  undef YYSTACK_RELOCATE
        if (yyss1 != yyssa)
          YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;

      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
                  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
        YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  if (yystate == YYFINAL)
    YYACCEPT;

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

  /* Do appropriate processing given the current state.  Read a
     lookahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to lookahead token.  */
  yyn = yypact[yystate];
  if (yypact_value_is_default (yyn))
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = yylex (&yylval, yyscanner);
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yytable_value_is_error (yyn))
        goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the lookahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);

  /* Discard the shifted token.  */
  yychar = YYEMPTY;

  yystate = yyn;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END

  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     '$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 2:
#line 144 "parser/serverFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_INFO, "the server file was empty");
}
#line 1453 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 3:
#line 148 "parser/serverFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %3-i: file: headers", LINENO);
}
#line 1461 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 4:
#line 152 "parser/serverFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %3-i: file: headers stanzas", LINENO);
}
#line 1469 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 5:
#line 158 "parser/serverFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %3-i: headers: headers header", LINENO);
}
#line 1477 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 6:
#line 162 "parser/serverFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %3-i: headers: header", LINENO);
}
#line 1485 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 7:
#line 168 "parser/serverFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i master server: %s", LINENO, (yyvsp[0].hash));
  if (!(coll->serverTree->master = addServer(coll, (yyvsp[0].hash)))) YYABORT;
}
#line 1494 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 8:
#line 173 "parser/serverFile.y" /* yacc.c:1646  */
    {
  strncpy(coll->serverTree->dnsHost, (yyvsp[0].string), MAX_SIZE_HOST);
}
#line 1502 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 9:
#line 177 "parser/serverFile.y" /* yacc.c:1646  */
    {
  strncpy(coll->serverTree->aesKey, (yyvsp[0].string), MAX_SIZE_AES);
}
#line 1510 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 10:
#line 181 "parser/serverFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i https %s", LINENO, (yyvsp[0].boolean)?"yes":"no");
  coll->serverTree->doHttps = (yyvsp[0].boolean);
}
#line 1519 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 11:
#line 186 "parser/serverFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i logApache %s", LINENO, (yyvsp[0].boolean)?"yes":"no");
  if ((yyvsp[0].boolean)) {
    coll->serverTree->log |= APACHE;
  }
  else {
    coll->serverTree->log &= ~APACHE;
  }
}
#line 1533 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 12:
#line 196 "parser/serverFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i logGit %s", LINENO, (yyvsp[0].boolean)?"yes":"no");
  if ((yyvsp[0].boolean)) {
    coll->serverTree->log |= GIT;
  }
  else {
    coll->serverTree->log &= ~GIT;
  }
}
#line 1547 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 13:
#line 206 "parser/serverFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i logAudit %s", LINENO, (yyvsp[0].boolean)?"yes":"no");
  if ((yyvsp[0].boolean)) {
    coll->serverTree->log |= AUDIT;
  }
  else {
    coll->serverTree->log &= ~AUDIT;
  }
}
#line 1561 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 14:
#line 216 "parser/serverFile.y" /* yacc.c:1646  */
    {
  coll->serverTree->serverTTL = (yyvsp[-1].number)*(yyvsp[0].time);
}
#line 1569 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 15:
#line 220 "parser/serverFile.y" /* yacc.c:1646  */
    {
  coll->serverTree->scoreParam.suppTTL = (yyvsp[-1].number)*(yyvsp[0].time);
}
#line 1577 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 16:
#line 224 "parser/serverFile.y" /* yacc.c:1646  */
    {
  coll->serverTree->uploadTTL = (yyvsp[-1].number)*(yyvsp[0].time);
}
#line 1585 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 17:
#line 228 "parser/serverFile.y" /* yacc.c:1646  */
    {
   coll->serverTree->scoreParam.maxScore = (yyvsp[0].score);
}
#line 1593 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 18:
#line 232 "parser/serverFile.y" /* yacc.c:1646  */
    {
  coll->serverTree->scoreParam.badScore = (yyvsp[0].score);
}
#line 1601 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 19:
#line 236 "parser/serverFile.y" /* yacc.c:1646  */
    {
  coll->serverTree->scoreParam.powSupp = (yyvsp[0].score);
}
#line 1609 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 20:
#line 240 "parser/serverFile.y" /* yacc.c:1646  */
    {
  coll->serverTree->scoreParam.factSupp = (yyvsp[0].score);
}
#line 1617 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 21:
#line 244 "parser/serverFile.y" /* yacc.c:1646  */
    {
   coll->serverTree->scoreParam.fileScore = (yyvsp[0].score);
}
#line 1625 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 22:
#line 248 "parser/serverFile.y" /* yacc.c:1646  */
    {
  coll->serverTree->minGeoDup = (yyvsp[0].number);
}
#line 1633 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 23:
#line 254 "parser/serverFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %3-i: stanzas: stanzas stanza", LINENO);
}
#line 1641 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 24:
#line 258 "parser/serverFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %3-i: stanzas: stanza", LINENO);
}
#line 1649 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 25:
#line 264 "parser/serverFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %3-i: servSERVER server lines servENDBLOCK", 
	    LINENO);
  server->user = destroyString(server->user);
  if (isEmptyString(server->label)) {
    if (!(server->user = createString(env.confLabel))) YYABORT;
  }
  else {
    if (!(server->user = createString(server->label))) YYABORT;
  }
  if (!(server->user = catString(server->user, "-"))) YYABORT;
  if (!(server->user = 
	catString(server->user, coll->label))) YYABORT;
}
#line 1668 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 26:
#line 281 "parser/serverFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i new server: %s", LINENO, (yyvsp[0].hash));
  if (!(server = addServer(coll, (yyvsp[0].hash)))) YYABORT;
}
#line 1677 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 31:
#line 294 "parser/serverFile.y" /* yacc.c:1646  */
    {
  if (!(server->label = createString((yyvsp[0].string)))) YYERROR;
}
#line 1685 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 32:
#line 298 "parser/serverFile.y" /* yacc.c:1646  */
    {
  if (!(server->comment = createString((yyvsp[0].string)))) YYERROR;
}
#line 1693 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 33:
#line 302 "parser/serverFile.y" /* yacc.c:1646  */
    {
  strncpy(server->host, (yyvsp[0].string), MAX_SIZE_HOST);
}
#line 1701 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 34:
#line 306 "parser/serverFile.y" /* yacc.c:1646  */
    {
  server->lastCommit = (yyvsp[0].time);
}
#line 1709 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 37:
#line 312 "parser/serverFile.y" /* yacc.c:1646  */
    {
  if (server) server->mdtxPort = (int)(yyvsp[0].number);
}
#line 1717 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 38:
#line 316 "parser/serverFile.y" /* yacc.c:1646  */
    {
  if (server) server->sshPort = (int)(yyvsp[0].number);
}
#line 1725 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 39:
#line 320 "parser/serverFile.y" /* yacc.c:1646  */
    {
  if (server) server->wwwPort = (int)(yyvsp[0].number);
}
#line 1733 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 40:
#line 324 "parser/serverFile.y" /* yacc.c:1646  */
    {
  if (!(server->userKey = createString((yyvsp[0].string)))) YYERROR;
}
#line 1741 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 41:
#line 328 "parser/serverFile.y" /* yacc.c:1646  */
    {
  if (!(server->hostKey = createString((yyvsp[0].string)))) YYERROR;
}
#line 1749 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 42:
#line 332 "parser/serverFile.y" /* yacc.c:1646  */
    {
  if (server) server->cacheSize = (yyvsp[-1].number)*(yyvsp[0].size);
}
#line 1757 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 43:
#line 336 "parser/serverFile.y" /* yacc.c:1646  */
    {
  if (server) server->cacheTTL = (yyvsp[-1].number)*(yyvsp[0].time);
}
#line 1765 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 44:
#line 340 "parser/serverFile.y" /* yacc.c:1646  */
    {
  if (server) server->queryTTL = (yyvsp[-1].number)*(yyvsp[0].time);
}
#line 1773 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 48:
#line 351 "parser/serverFile.y" /* yacc.c:1646  */
    {
  Archive* archive = 0;
  Image* image = 0;

  // score is log as 0 if we log it in 4rst position ?!
  // score is log as previous value if we log it in 3rd position ?!
  logParser(LOG_DEBUG, "line %-3i new image %s:%lli", LINENO, (yyvsp[-4].hash), (yyvsp[-2].number));
  logParser(LOG_DEBUG, "score = %.2f", (yyvsp[0].score));

  if (server) {
    if (!(archive = addArchive(coll, (yyvsp[-4].hash), (yyvsp[-2].number)))) YYERROR;
    if (!(image = addImage(coll, server, archive))) YYERROR;
    image->score = (yyvsp[0].score);
  } else {
    logParser(LOG_ERR, "line %-3i: server not found (internal error)",
	      LINENO);
    YYABORT;
  }
}
#line 1797 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 53:
#line 381 "parser/serverFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i network: %s", LINENO, (yyvsp[0].string));
  if (!addNetworkToRing(server->networks, (yyvsp[0].string))) YYABORT;
}
#line 1806 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;

  case 54:
#line 388 "parser/serverFile.y" /* yacc.c:1646  */
    {
  logParser(LOG_DEBUG, "line %-3i gateway: %s", LINENO, (yyvsp[0].string));
  if (!addNetworkToRing(server->gateways, (yyvsp[0].string))) YYABORT;
}
#line 1815 "parser/serverFile.tab.c" /* yacc.c:1646  */
    break;


#line 1819 "parser/serverFile.tab.c" /* yacc.c:1646  */
      default: break;
    }
  /* User semantic actions sometimes alter yychar, and that requires
     that yytoken be updated with the new translation.  We take the
     approach of translating immediately before every use of yytoken.
     One alternative is translating here after every semantic action,
     but that translation would be missed if the semantic action invokes
     YYABORT, YYACCEPT, or YYERROR immediately after altering yychar or
     if it invokes YYBACKUP.  In the case of YYABORT or YYACCEPT, an
     incorrect destructor might then be invoked immediately.  In the
     case of YYERROR or YYBACKUP, subsequent parser actions might lead
     to an incorrect destructor call or verbose syntax error message
     before the lookahead is translated.  */
  YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;

  /* Now 'shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*--------------------------------------.
| yyerrlab -- here on detecting error.  |
`--------------------------------------*/
yyerrlab:
  /* Make sure we have latest lookahead translation.  See comments at
     user semantic actions for why this is necessary.  */
  yytoken = yychar == YYEMPTY ? YYEMPTY : YYTRANSLATE (yychar);

  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if ! YYERROR_VERBOSE
      yyerror (yyscanner, coll, server, YY_("syntax error"));
#else
# define YYSYNTAX_ERROR yysyntax_error (&yymsg_alloc, &yymsg, \
                                        yyssp, yytoken)
      {
        char const *yymsgp = YY_("syntax error");
        int yysyntax_error_status;
        yysyntax_error_status = YYSYNTAX_ERROR;
        if (yysyntax_error_status == 0)
          yymsgp = yymsg;
        else if (yysyntax_error_status == 1)
          {
            if (yymsg != yymsgbuf)
              YYSTACK_FREE (yymsg);
            yymsg = (char *) YYSTACK_ALLOC (yymsg_alloc);
            if (!yymsg)
              {
                yymsg = yymsgbuf;
                yymsg_alloc = sizeof yymsgbuf;
                yysyntax_error_status = 2;
              }
            else
              {
                yysyntax_error_status = YYSYNTAX_ERROR;
                yymsgp = yymsg;
              }
          }
        yyerror (yyscanner, coll, server, yymsgp);
        if (yysyntax_error_status == 2)
          goto yyexhaustedlab;
      }
# undef YYSYNTAX_ERROR
#endif
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
         error, discard it.  */

      if (yychar <= YYEOF)
        {
          /* Return failure if at end of input.  */
          if (yychar == YYEOF)
            YYABORT;
        }
      else
        {
          yydestruct ("Error: discarding",
                      yytoken, &yylval, yyscanner, coll, server);
          yychar = YYEMPTY;
        }
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:

  /* Pacify compilers like GCC when the user code never invokes
     YYERROR and the label yyerrorlab therefore never appears in user
     code.  */
  if (/*CONSTCOND*/ 0)
     goto yyerrorlab;

  /* Do not reclaim the symbols of the rule whose action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;      /* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (!yypact_value_is_default (yyn))
        {
          yyn += YYTERROR;
          if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
            {
              yyn = yytable[yyn];
              if (0 < yyn)
                break;
            }
        }

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
        YYABORT;


      yydestruct ("Error: popping",
                  yystos[yystate], yyvsp, yyscanner, coll, server);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END


  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#if !defined yyoverflow || YYERROR_VERBOSE
/*-------------------------------------------------.
| yyexhaustedlab -- memory exhaustion comes here.  |
`-------------------------------------------------*/
yyexhaustedlab:
  yyerror (yyscanner, coll, server, YY_("memory exhausted"));
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
  if (yychar != YYEMPTY)
    {
      /* Make sure we have latest lookahead translation.  See comments at
         user semantic actions for why this is necessary.  */
      yytoken = YYTRANSLATE (yychar);
      yydestruct ("Cleanup: discarding lookahead",
                  yytoken, &yylval, yyscanner, coll, server);
    }
  /* Do not reclaim the symbols of the rule whose action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
                  yystos[*yyssp], yyvsp, yyscanner, coll, server);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
#if YYERROR_VERBOSE
  if (yymsg != yymsgbuf)
    YYSTACK_FREE (yymsg);
#endif
  return yyresult;
}
#line 394 "parser/serverFile.y" /* yacc.c:1906  */


/* epilogue: =======================================================*/


/*=======================================================================
 * Function   : parsererror
 * Description: Emit an error message. Called by the parser on error
 *              state.
 * Synopsis   : void parsererror(char* message)
 * Input      : char* message = the error message.
 * Output     : N/A
 =======================================================================*/
void serv_error(yyscan_t yyscanner, Collection* coll, Server* server,
		const char* message)
{
  logParser(LOG_ERR, "%s on token '%s' line %i",
	  message, serv_get_text(yyscanner), LINENO);
}


/*=======================================================================
 * Function   : parseServerList
 * Description: Parse a server file
 * Synopsis   : int parseServerList(const char* path)
 * Input      : const char* path: the file to parse
 * Output     : TRUE on success
=======================================================================*/
int parseServerFile(Collection* coll, const char* path)
{ 
  int rc = FALSE;
  FILE* inputStream = stdin;
  yyscan_t scanner;
  Server* server = 0;

  checkCollection(coll);
  logParser(LOG_INFO, "parse %s servers from %s",
	    coll->label, path?path:"stdin");

  // initialise scanner
  if (serv_lex_init(&scanner)) {
    logParser(LOG_ERR, "%s", "error initializing scanner");
    goto error;
  }

  if (path != 0) {
    if (!(inputStream = fopen(path, "r"))) {
      logParser(LOG_ERR, "cannot open input stream %s: %s",
		path, strerror(errno)); 
      goto error;
    }
  }

  serv_set_in(inputStream, scanner);

  // debug mode for scanner
  serv_set_debug(env.debugLexer, scanner);
  logParser(LOG_DEBUG, "serv_set_debug = %i", serv_get_debug(scanner));

  // call the parser
  if (serv_parse(scanner, coll, server)) {
    logParser(LOG_ERR, "servers file parser error on line %i",
	    serv_get_lineno(scanner));
    logParser(LOG_ERR, "please edit %s", path?path:"stdin");
    goto error2;
  }

  rc = TRUE;
 error2:
  if (inputStream != stdin) {
    fclose(inputStream);
  }
 error:
  if (!rc) {
    logParser(LOG_ERR, "%s", "servers file parser error");
  }
  serv_lex_destroy(scanner);
  return rc;
}

/* Local Variables: */
/* mode: c */
/* mode: font-lock */
/* mode: auto-fill */
/* End: */
